Concise CSS

# Giga Helper text

# Mega Helper text

# Kilo Helper text

# Heading 1 Helper link

## Heading 2 Helper text

### Heading 3 Helper text

#### Heading 4 Helper text

##### Heading 5 Helper text

###### Heading 6 Helper text

Lorem ipsum dolor sit amet, `sadipscing` `elitr`, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam voluptua. At vero eos et accusam et justo duo dolores et ea rebum. Stet clita kasd gubergren, no sea takimata sanctus est Lorem ipsum dolor sit amet. Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam voluptua.

At vero eos et accusam et justo duo dolores et ea rebum. Stet clita kasd gubergren, no sea takimata sanctus est Lorem ipsum dolor sit amet. Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam voluptua. At vero eos et accusam et justo duo dolores et ea rebum. Stet clita kasd gubergren, no sea takimata sanctus est Lorem ipsum dolor sit amet.

Left text

Center text

Right text

> This is a blockquote.

> This is a reverse blockquote.

> John Doe

    .class {
        background-color: #ccc;
    }

    .class {
        background-color: #ccc;
    }

- List Item
- List Item
- List Item
- List Item
  - List Item
  - List Item
    - List Item
- List Item

1. List Item
2. List Item
   1. List Item
      1. List Item
3. List Item

- List item
- List item
- List item

- List item
- List item
- List item

Definition
  Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam voluptua.
List
  Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam voluptua.

Definition
  Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam voluptua.
List
  Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam voluptua.

# | First Name | Last Name
--- | --- | ---
1 | John | Doe
2 | Jane | Doe

# | First Name | Last Name
--- | --- | ---
1 | John | Doe
2 | Jane | Doe

# | First Name | Last Name
--- | --- | ---
1 | John | Doe
2 | Jane | Doe

# | First Name | Last Name
--- | --- | ---
1 | John | Doe
2 | Jane | Doe

# | First Name | Last Name
--- | --- | ---
1 | John | Doe
2 | Jane | Doe

# | First Name | Last Name
--- | --- | ---
1 | John | Doe
2 | Jane | Doe

# | First Name | Last Name
--- | --- | ---
1 | John | Doe
2 | Jane | Doe
3 | John | Doe

# | First Name | Last Name
--- | --- | ---
1 | John | Doe
2 | Jane | Doe
3 | John | Doe

First Name: Here is some help text

Last Name:

Success Input:

Warning Input:

Error Input:

Email:

Website:

Gender: Male
Female

Reason for contact: Message
Quote

Message:

Files

Username: Password:
Name:

Here is some help text

Email:
Modal Header ×

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Duis eget bibendum eros. Integer rhoncus pretium orci ut sagittis. Proin sollicitudin sapien eu dui imperdiet, et viverra enim dignissim.

Modal Header ×

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Duis eget bibendum eros. Integer rhoncus pretium orci ut sagittis. Proin sollicitudin sapien eu dui imperdiet, et viverra enim dignissim.

Modal Header ×

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Duis eget bibendum eros. Integer rhoncus pretium orci ut sagittis. Proin sollicitudin sapien eu dui imperdiet, et viverra enim dignissim.

Modal Header ×

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Duis eget bibendum eros. Integer rhoncus pretium orci ut sagittis. Proin sollicitudin sapien eu dui imperdiet, et viverra enim dignissim.

Modal Header ×

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Duis eget bibendum eros. Integer rhoncus pretium orci ut sagittis. Proin sollicitudin sapien eu dui imperdiet, et viverra enim dignissim.

Open Modal

Open Small Modal

Open Large Modal

Open Full Modal

Open Flat Modal

Label

25

Top tooltip

Right tooltip

Bottom tooltip

Left tooltip

Persistent Tooltip

×

Alert! This is a standard message for your application.

×

Success! This is a success message for your application.

×

Warning! This is a warning for your application.

×

Error! This is an error for your application.

### Card Title

Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat.

### Card Title

Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat.

### Collection Header

Collection Item
Active Collection Item
Collection Item
Collection Item Active Collection Item Collection Item

- Left
- Center
- Right

- First
- 1
- 2
- 3
- 4
- Last

50%
25%
75%
Dropdown Button »

- Home
- Account
- Settings

Dropdown

- Home
- Account
- Settings

Dropdown Small

- Home
- Account
- Settings

Dropdown Large

- Home
- Account
- Settings

Dropdown Top

- Home
- Account
- Settings

Dropdown Content

Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy.

Dropdown Hover

Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy.